@@ -1,6 +1,6 @@
 package Bundle::Slash;
 
-$Bundle::Slash::VERSION = '2.10';
+$Bundle::Slash::VERSION = '2.12';
 
 1;
 
@@ -35,14 +35,18 @@ MIME::Base64            - why after URI if URI needs it?
 
 Bundle::LWP		- URI,HTML::Parser,MIME::Base64
 
+HTML::Element           - For doing HTML-to-text
+
+Font::AFM               - ditto
+
+HTML::FormatText        - ditto
+
 XML::Parser
 
 XML::RSS
 
 DBI
 
-DBI::FAQ
-
 Data::ShowTable
 
 J/JW/JWIED/Msql-Mysql-modules-1.2216.tar.gz    - instead of Bundle::DBD::mysql (Data::ShowTable)
@@ -71,8 +75,6 @@ Date::Manip             - Still needed, but not for long
 
 Date::Parse		- TimeDate
 
-Time::ParseDate         - Time-modules
-
 Time::HiRes
 
 Schedule::Cron
